# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class ReportTransmissionCode(str, enum.Enum):
    CBM = "BM"
    """
    By Mail
    """

    CEL = "EL"
    """
    Electronically Only
    """

    CFX = "FX"
    """
    By Fax
    """

    _UNKNOWN = "__REPORTTRANSMISSIONCODE_UNKNOWN__"
    """
    This member is used for forward compatibility. If the value is not recognized by the enum, it will be stored here, and the raw value is accessible through `.value`.
    """

    @classmethod
    def _missing_(cls, value: typing.Any) -> "ReportTransmissionCode":
        unknown = cls._UNKNOWN
        unknown._value_ = value
        return unknown

    def visit(
        self,
        cbm: typing.Callable[[], T_Result],
        cel: typing.Callable[[], T_Result],
        cfx: typing.Callable[[], T_Result],
        _unknown_member: typing.Callable[[str], T_Result],
    ) -> T_Result:
        if self is ReportTransmissionCode.CBM:
            return cbm()
        if self is ReportTransmissionCode.CEL:
            return cel()
        if self is ReportTransmissionCode.CFX:
            return cfx()
        return _unknown_member(self._value_)
