# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ......core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .rate import Rate
from .rate_upload import RateUpload
from .validation_error import ValidationError


class RateUploadWithPossibleErrors(UniversalBaseModel):
    rate_upload: RateUpload
    existing_rate: typing.Optional[Rate] = None
    possible_errors: typing.List[ValidationError]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
