# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ......core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .clinical_trial_phase import ClinicalTrialPhase


class MutableClinicalTrial(UniversalBaseModel):
    name: str
    clinical_trial_number: str = pydantic.Field()
    """
    Must be 8 characters long
    """

    clinical_trial_phase: typing.Optional[ClinicalTrialPhase] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
