# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ....core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .state import State


class StreetAddressOptionalBase(UniversalBaseModel):
    address_1: typing.Optional[str] = pydantic.Field(alias="address1", default=None)
    address_2: typing.Optional[str] = pydantic.Field(alias="address2", default=None)
    city: typing.Optional[str] = None
    state: typing.Optional[State] = None
    zip_code: typing.Optional[str] = pydantic.Field(default=None)
    """
    5-digit zip code
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
