# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ......core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .....commons.types.service_line_id import ServiceLineId
from .claim_invoice_item import ClaimInvoiceItem
from .service_line_invoice_item import ServiceLineInvoiceItem


class ClaimInvoiceItemInfo(UniversalBaseModel):
    claim_invoice_item: typing.Optional[ClaimInvoiceItem] = None
    service_line_invoice_items: typing.Dict[ServiceLineId, ServiceLineInvoiceItem]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
