# This file was auto-generated by Fern from our API Definition.

import typing

from ....core.api_error import ApiError
from ..types.entity_not_found_error_message import EntityNotFoundErrorMessage


class EntityNotFoundError(ApiError):
    def __init__(self, body: EntityNotFoundErrorMessage, headers: typing.Optional[typing.Dict[str, str]] = None):
        super().__init__(status_code=404, headers=headers, body=body)
