# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ........core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .eligibility_check_error_details import EligibilityCheckErrorDetails
from .eligibility_check_error_source import EligibilityCheckErrorSource


class EligibilityCheckError(UniversalBaseModel):
    source: EligibilityCheckErrorSource
    error_details: EligibilityCheckErrorDetails = pydantic.Field(alias="errorDetails")

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
