# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ........core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .eligibility_recommendation_patient_info import EligibilityRecommendationPatientInfo
from .eligibility_recommendation_payload import EligibilityRecommendationPayload


class PostEligibilityRecommendationRequest(UniversalBaseModel):
    eligibility_check_id: str
    patient: EligibilityRecommendationPatientInfo
    recommendation: EligibilityRecommendationPayload

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
