# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ........core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .....common.types.address import Address
from .....common.types.contact_point import ContactPoint
from .....common.types.human_name import HumanName
from .....common.types.period import Period
from .....common.types.relationship import Relationship


class Contact(UniversalBaseModel):
    relationship: typing.List[Relationship]
    name: HumanName
    telecoms: typing.List[ContactPoint]
    addresses: typing.List[Address]
    period: typing.Optional[Period] = None
    hipaa_authorization: typing.Optional[bool] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
