# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ......core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .....commons.types.street_address_long_zip import StreetAddressLongZip
from .address_type import AddressType


class OrganizationProviderAddress(UniversalBaseModel):
    address: StreetAddressLongZip = pydantic.Field()
    """
    The address of the provider
    """

    address_type: AddressType = pydantic.Field()
    """
    The address type of the provider
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
